@@ -12,7 +12,7 @@ pub static EXCLUDE_NEWER: &str = "2023-11-18T12:00:00Z";
 #[allow(unused)]
 pub const INSTA_FILTERS: &[(&str, &str)] = &[
     // TODO(charlie): This should be `debug` logging in uv, but it's going to `stdout` on Windows.
-    (r"Using Python \d+\.\d+\.\d+ environment at \.venv\n", ""),
+    (r"Using Python \d+\.\d+\.\d+ environment at: \.venv\n", ""),
     // general temp folders
     (
         r"(\b[A-Z]:)?[\\/].*?[\\/]\.rye-tests---[^\\/]+[\\/]",
@@ -67,8 +67,8 @@ toolchain = "cpython@3.12.6"
     // build info to make sure we cover our grounds here.
     for (version, build_info) in [
         ("cpython@3.8.20", false),
-        ("cpython@3.11.10", true),
-        ("cpython@3.12.6", false),
+        ("cpython@3.11.11", true),
+        ("cpython@3.12.8", false),
         ("pypy@3.10.13", false),
     ] {
         if home.join("py").join(version).is_dir() {
